@@ -11,8 +11,8 @@ from teamplify_runner.utils import cd, run
 
 
 IMAGES = {
-    'db': 'mysql:8.0.23',
-    'redis': 'redis:6.0.5',
+    'db': 'mysql:8.0.29-oracle',
+    'redis': 'redis:6.2.6',
     'nginx': 'jwilder/nginx-proxy:latest',
     'letsencrypt': 'jrcs/letsencrypt-nginx-proxy-companion:latest',
     'smtp': 'instrumentisto/postfix:3.1.3',
@@ -33,7 +33,14 @@ def _start(env):
     run('mkdir -p %s' % env['DB_BACKUP_MOUNT'])
     with cd(BASE_DIR):
         run(
-            'docker-compose up -d --remove-orphans',
+            'docker-compose up '
+            '--detach '
+            '--remove-orphans '
+            '--scale worker_slim={worker_slim_count} '
+            '--scale worker_fat={worker_fat_count}'.format(
+                worker_slim_count=env['WORKER_SLIM_COUNT'],
+                worker_fat_count=env['WORKER_FAT_COUNT'],
+            ),
             capture_output=False,
             env=env,
         )
@@ -116,11 +123,12 @@ def _backup(env, filename=None):
         target_file = os.path.join(filename, default_filename)
     else:
         target_file = filename
+    temp_filename = os.path.join('/backup', default_filename)
     cleanup_on_error = not os.path.exists(target_file)
-    try:
-        run('touch %s' % target_file)  # quick check for write access
-    except RuntimeError:
-        exit(1)
+    # check for write access on the host
+    run('touch %s' % target_file)
+    # check for write access inside docker
+    run('docker exec teamplify_db bash -c "touch %s"' % temp_filename)
     command = (
         'MYSQL_PWD={password} mysqldump --single-transaction -u{user} '
         '-h {host} {db} | gzip > {filename}'.format(
@@ -134,13 +142,15 @@ def _backup(env, filename=None):
     click.echo('Making backup of Teamplify DB to:\n -> %s' % target_file)
     click.echo('Please wait...')
     try:
-        run('docker exec teamplify_db bash -c "{command}"'.format(
-            command=command,
-        ))
-    except RuntimeError as e:
+        run(
+            'docker exec teamplify_db bash -c "{command}"'.format(
+                command=command,
+            ),
+            exit_on_error=False,
+        )
+    except RuntimeError:
         if cleanup_on_error:
             run('rm %s' % target_file)
-        click.echo(str(e), err=True)
         exit(1)
     run('mv {source} {target}'.format(
         source=os.path.join(env['DB_BACKUP_MOUNT'], default_filename),
